@@ -14,11 +14,18 @@ def test_header_and_footer_refs_in_paragraph_props_get_removed(header_footer):
     assert len(refs) == 0
 
 
+def test_master_header_and_footer_are_preserved_when_adding_sections():
+    doc = FixtureDocument("master_header_footer_with_sections.docx")
+    composed = ComposedDocument(
+        "master_header_footer.docx", "header_footer_sections.docx")
+
+    assert composed == doc
+
+
 def test_header_footer():
     doc = FixtureDocument("header_footer.docx")
     composed = ComposedDocument(
         "header_footer.docx", "header_footer.docx")
-
     assert composed == doc
 
 
